@@ -61,6 +61,7 @@ fn generate_bindings(src_dir: path::PathBuf) {
         .allowlist_function("libbpf_.+")
         .allowlist_function("perf_.+")
         .allowlist_function("ring_buffer_.+")
+        .allowlist_function("user_ring_buffer_.+")
         .allowlist_function("vdprintf")
         .allowlist_type("bpf_.+")
         .allowlist_type("btf_.+")
@@ -219,7 +220,7 @@ fn make_zlib(compiler: &cc::Tool, src_dir: &path::Path, out_dir: &path::Path) {
     let status = process::Command::new("make")
         .arg("install")
         .arg("-j")
-        .arg(&format!("{}", num_cpus::get()))
+        .arg(&format!("{}", num_cpus()))
         .current_dir(&src_dir.join("zlib"))
         .status()
         .expect("could not execute make");
@@ -297,7 +298,7 @@ fn make_elfutils(compiler: &cc::Tool, src_dir: &path::Path, out_dir: &path::Path
     let status = process::Command::new("make")
         .arg("install")
         .arg("-j")
-        .arg(&format!("{}", num_cpus::get()))
+        .arg(&format!("{}", num_cpus()))
         .arg("BUILD_STATIC_ONLY=y")
         .current_dir(&src_dir.join("elfutils"))
         .status()
@@ -327,7 +328,7 @@ fn make_libbpf(
     let status = process::Command::new("make")
         .arg("install")
         .arg("-j")
-        .arg(&format!("{}", num_cpus::get()))
+        .arg(&format!("{}", num_cpus()))
         .env("BUILD_STATIC_ONLY", "y")
         .env("PREFIX", "/")
         .env("LIBDIR", "")
@@ -349,3 +350,7 @@ fn make_libbpf(
 
     assert!(status.success(), "make failed");
 }
+
+fn num_cpus() -> usize {
+    std::thread::available_parallelism().map_or(1, |count| count.get())
+}
