@@ -4,7 +4,7 @@ DOCKER="docker"
 
 set -eu -o pipefail
 
-${DOCKER} build -t libbpf-sys-builder - <<'EOF'
+${DOCKER} build --platform linux/amd64 -t libbpf-sys-builder - <<'EOF'
 FROM amd64/ubuntu:jammy AS libbpf-sys-builder
 
 ENV LANG=C.UTF-8 \
@@ -26,7 +26,7 @@ RUN \
 
 ENTRYPOINT \
 	source $HOME/.cargo/env; \
-	cargo build --features bindgen --release --verbose;
+	cargo build --features bindgen-source --release --verbose;
 EOF
 
-${DOCKER} run --rm -v "$(pwd):/usr/local/src/libbpf-sys" libbpf-sys-builder
+${DOCKER} run --platform linux/amd64 --rm -v "$(pwd):/usr/local/src/libbpf-sys" libbpf-sys-builder
